# SPDX-FileCopyrightText: 2024 Luca Weiss
# SPDX-License-Identifier: GPL-3.0-only

import sys
import gi
gi.require_version('Gtk', '4.0')
gi.require_version('Adw', '1')
from gi.repository import Adw
from gi.repository import Gtk, Gdk, Gio, GLib, GObject

from .config import APP_NAME, APP_ID, APP_VERSION
from .mainwindow import MainWindow
from .widgets import ESimProfileWidget


class Application(Gtk.Application):
    def __init__(self):
        super().__init__(application_id=APP_ID,
                         flags=Gio.ApplicationFlags.FLAGS_NONE)
        GLib.set_application_name(APP_NAME)
        GLib.set_prgname(APP_ID)

        display = Gdk.Display.get_default()

        # custom css
        css_provider = Gtk.CssProvider()
        css_provider.load_from_resource("/eu/lucaweiss/lpa-gtk/lpa-gtk.css")
        Gtk.StyleContext.add_provider_for_display(
            display,
            css_provider,
            Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)

    def run(self, argv):
        self.connect("startup", self.on_startup)
        self.connect("activate", self.on_activate)
        return super().run(argv)

    def on_startup(self, *_):
        Adw.init()

        self._add_action('about', None, None, self.show_about)

    def _add_action(self, name, parameter_type, accels, activate_cbk):
        action = Gio.SimpleAction.new(name, parameter_type)
        action.connect("activate", activate_cbk)
        self.add_action(action)
        if accels is not None:
            self.set_accels_for_action(F"app.{name}", accels)
        return action

    def on_activate(self, *_):
        win = self.props.active_window
        if not win:
            win = MainWindow(application=self)
        win.present()

    def show_about(self, *args):
        Adw.AboutWindow(
            application_name=APP_NAME,
            application_icon=APP_ID,
            version=APP_VERSION,
            copyright="© 2024 Luca Weiss",
            website="https://codeberg.org/lucaweiss/lpa-gtk",
            issue_url="https://codeberg.org/lucaweiss/lpa-gtk/issues",
            developers=["Luca Weiss"],
            # Translators: about dialog text; this string should be replaced by a text crediting yourselves and your translation team, or should be left empty. Do not translate literally!
            translator_credits=_("translator-credits"),
            comments=_("eSIM Local Profile Agent"),
            license_type=Gtk.License.GPL_3_0
        ).show()


def main():
    app = Application()
    return app.run(sys.argv)
